Module approval

Module approval 

Structs

ApprovalState
SimpleApprovalRequest
Simple approval request for UI (doesn’t require update_id since it’s in the path)
SimpleRejectionRequest
Simple rejection request for UI (doesn’t require update_id since it’s in the path)

Functions

approve_update
reject_update
start_approval_server
update_helmrelease_chart_version
Update a HelmRelease chart version directly This function is public so it can be used both from the approval workflow and from direct updates in the Helm controller