Structs
- Approval
State - Simple
Approval Request - Simple approval request for UI (doesn’t require update_id since it’s in the path)
- Simple
Rejection Request - Simple rejection request for UI (doesn’t require update_id since it’s in the path)
Functions
- approve_
update - reject_
update - start_
approval_ server - update_
helmrelease_ chart_ version - Update a HelmRelease chart version directly This function is public so it can be used both from the approval workflow and from direct updates in the Helm controller